@@ -11,11 +11,11 @@
 # error "Missing MKC_FEATURES += progname"
 #endif
 
-#ifdef MKC_PROGNAME_IS_FINE
-
 #include <stdlib.h>
 
-#else
+#include "mkc_externc.h"
+
+__MKC_BEGIN_DECLS
 
 #if !HAVE_FUNC1_SETPROGNAME_STDLIB_H
 void setprogname (const char *progname);
@@ -25,6 +25,6 @@ void setprogname (const char *progname);
 const char * getprogname (void);
 #endif
 
-#endif /* MKC_PROGNAME_IS_FINE */
+__MKC_END_DECLS
 
 #endif // _MKC_PROGNAME_H_
